==> openshift-model-miscellaneous-5.12.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/BMCDetailsBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class BMCDetailsBuilder extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetailsFluentImpl<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetailsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetails,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetailsBuilder>{
  public BMCDetailsBuilder() {
    this(false);
  }
  public BMCDetailsBuilder(java.lang.Boolean validationEnabled) {
    this(new BMCDetails(), validationEnabled);
  }
  public BMCDetailsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetailsFluent<?> fluent) {
    this(fluent, false);
  }
  public BMCDetailsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetailsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new BMCDetails(), validationEnabled);
  }
  public BMCDetailsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetailsFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetails instance) {
    this(fluent, instance, false);
  }
  public BMCDetailsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetailsFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetails instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAddress(instance.getAddress()); 
    fluent.withCredentialsName(instance.getCredentialsName()); 
    fluent.withDisableCertificateVerification(instance.getDisableCertificateVerification()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public BMCDetailsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetails instance) {
    this(instance,false);
  }
  public BMCDetailsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetails instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAddress(instance.getAddress()); 
    this.withCredentialsName(instance.getCredentialsName()); 
    this.withDisableCertificateVerification(instance.getDisableCertificateVerification()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetailsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BMCDetails build() {
    BMCDetails buildable = new BMCDetails(fluent.getAddress(),fluent.getCredentialsName(),fluent.getDisableCertificateVerification());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BMCDetailsBuilder that = (BMCDetailsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-6.6.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/BMCDetailsBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class BMCDetailsBuilder extends BMCDetailsFluentImpl<BMCDetailsBuilder> implements VisitableBuilder<BMCDetails,BMCDetailsBuilder>{
  public BMCDetailsBuilder() {
    this(false);
  }
  public BMCDetailsBuilder(Boolean validationEnabled) {
    this(new BMCDetails(), validationEnabled);
  }
  public BMCDetailsBuilder(BMCDetailsFluent<?> fluent) {
    this(fluent, false);
  }
  public BMCDetailsBuilder(BMCDetailsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new BMCDetails(), validationEnabled);
  }
  public BMCDetailsBuilder(BMCDetailsFluent<?> fluent,BMCDetails instance) {
    this(fluent, instance, false);
  }
  public BMCDetailsBuilder(BMCDetailsFluent<?> fluent,BMCDetails instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAddress(instance.getAddress()); 
    fluent.withCredentialsName(instance.getCredentialsName()); 
    fluent.withDisableCertificateVerification(instance.getDisableCertificateVerification()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public BMCDetailsBuilder(BMCDetails instance) {
    this(instance,false);
  }
  public BMCDetailsBuilder(BMCDetails instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAddress(instance.getAddress()); 
    this.withCredentialsName(instance.getCredentialsName()); 
    this.withDisableCertificateVerification(instance.getDisableCertificateVerification()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  BMCDetailsFluent<?> fluent;
  Boolean validationEnabled;
  public BMCDetails build() {
    BMCDetails buildable = new BMCDetails(fluent.getAddress(),fluent.getCredentialsName(),fluent.getDisableCertificateVerification());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
